function _aws_cdk_aws_iot_actions_FirehoseRecordSeparator(p) {
}
function _aws_cdk_aws_iot_actions_CloudWatchLogsActionProps(p) {
}
function _aws_cdk_aws_iot_actions_CloudWatchPutMetricActionProps(p) {
}
function _aws_cdk_aws_iot_actions_KinesisPutRecordActionProps(p) {
}
function _aws_cdk_aws_iot_actions_CommonActionProps(p) {
}
function _aws_cdk_aws_iot_actions_SqsQueueActionProps(p) {
}
function _aws_cdk_aws_iot_actions_CloudWatchSetAlarmStateActionProps(p) {
}
function _aws_cdk_aws_iot_actions_CloudWatchPutMetricAction(p) {
}
function _aws_cdk_aws_iot_actions_LambdaFunctionAction(p) {
}
function _aws_cdk_aws_iot_actions_CloudWatchLogsAction(p) {
}
function _aws_cdk_aws_iot_actions_FirehosePutRecordActionProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.recordSeparator))
        _aws_cdk_aws_iot_actions_FirehoseRecordSeparator(p.recordSeparator);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_iot_actions_CloudWatchSetAlarmStateAction(p) {
}
function _aws_cdk_aws_iot_actions_KinesisPutRecordAction(p) {
}
function _aws_cdk_aws_iot_actions_FirehosePutRecordAction(p) {
}
function _aws_cdk_aws_iot_actions_S3PutObjectAction(p) {
}
function _aws_cdk_aws_iot_actions_SqsQueueAction(p) {
}
function _aws_cdk_aws_iot_actions_S3PutObjectActionProps(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_iot_actions_FirehoseRecordSeparator, _aws_cdk_aws_iot_actions_CloudWatchLogsActionProps, _aws_cdk_aws_iot_actions_CloudWatchPutMetricActionProps, _aws_cdk_aws_iot_actions_KinesisPutRecordActionProps, _aws_cdk_aws_iot_actions_CommonActionProps, _aws_cdk_aws_iot_actions_SqsQueueActionProps, _aws_cdk_aws_iot_actions_CloudWatchSetAlarmStateActionProps, _aws_cdk_aws_iot_actions_CloudWatchPutMetricAction, _aws_cdk_aws_iot_actions_LambdaFunctionAction, _aws_cdk_aws_iot_actions_CloudWatchLogsAction, _aws_cdk_aws_iot_actions_FirehosePutRecordActionProps, _aws_cdk_aws_iot_actions_CloudWatchSetAlarmStateAction, _aws_cdk_aws_iot_actions_KinesisPutRecordAction, _aws_cdk_aws_iot_actions_FirehosePutRecordAction, _aws_cdk_aws_iot_actions_S3PutObjectAction, _aws_cdk_aws_iot_actions_SqsQueueAction, _aws_cdk_aws_iot_actions_S3PutObjectActionProps };
module.exports.DeprecationError = DeprecationError;
